@@ -1,21 +1,3 @@
-## Copyright 2012-2016 Sebastian Gibb
-## <mail@sebastiangibb.de>
-##
-## This file is part of MALDIquant for R and related languages.
-##
-## MALDIquant is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## MALDIquant is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
-
 ## .calculateLabelPositions
 ##  calculate label positions to avoid collisions
 ##
@@ -35,7 +17,7 @@
 .calculateLabelPositions <- function(object, x, y, peakLabels, adj, cex, srt,
                                      maxSteps=100L) {
   ## start with smallest peak
-  i <- sort.int(y, index.return=TRUE, method="quick")$ix
+  i <- sort.int(y, index.return=TRUE)$ix
 
   ## calculate label rectangles
   rects <- .textLabelRects(x[i], y[i], peakLabels[i], adj=adj, cex=cex, srt=srt)
