@@ -13,5 +13,5 @@
 .localMaxima <- function(y, halfWindowSize=1L) {
   y <- c(rep.int(0L, halfWindowSize), y, rep.int(0L, halfWindowSize))
   i <- (halfWindowSize + 1L):(length(y) - halfWindowSize)
-  .Call("C_localMaxima", y, halfWindowSize)[i]
+  .Call(C_localMaxima, y, halfWindowSize)[i]
 }
